@@ -66,6 +66,8 @@ __all__ = (
     "DeregisterFromWorkMailRequestRequestTypeDef",
     "DescribeGroupRequestRequestTypeDef",
     "DescribeGroupResponseTypeDef",
+    "DescribeInboundDmarcSettingsRequestRequestTypeDef",
+    "DescribeInboundDmarcSettingsResponseTypeDef",
     "DescribeMailboxExportJobRequestRequestTypeDef",
     "DescribeMailboxExportJobResponseTypeDef",
     "DescribeOrganizationRequestRequestTypeDef",
@@ -124,6 +126,7 @@ __all__ = (
     "PaginatorConfigTypeDef",
     "PermissionTypeDef",
     "PutAccessControlRuleRequestRequestTypeDef",
+    "PutInboundDmarcSettingsRequestRequestTypeDef",
     "PutMailboxPermissionsRequestRequestTypeDef",
     "PutMobileDeviceAccessOverrideRequestRequestTypeDef",
     "PutRetentionPolicyRequestRequestTypeDef",
@@ -477,6 +480,21 @@ DescribeGroupResponseTypeDef = TypedDict(
     },
 )
 
+DescribeInboundDmarcSettingsRequestRequestTypeDef = TypedDict(
+    "DescribeInboundDmarcSettingsRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+    },
+)
+
+DescribeInboundDmarcSettingsResponseTypeDef = TypedDict(
+    "DescribeInboundDmarcSettingsResponseTypeDef",
+    {
+        "Enforced": bool,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeMailboxExportJobRequestRequestTypeDef = TypedDict(
     "DescribeMailboxExportJobRequestRequestTypeDef",
     {
@@ -1230,6 +1248,14 @@ class PutAccessControlRuleRequestRequestTypeDef(
     pass
 
 
+PutInboundDmarcSettingsRequestRequestTypeDef = TypedDict(
+    "PutInboundDmarcSettingsRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "Enforced": bool,
+    },
+)
+
 PutMailboxPermissionsRequestRequestTypeDef = TypedDict(
     "PutMailboxPermissionsRequestRequestTypeDef",
     {
